**# DATA ORGANIZATION
clear
use data_full_raw.dta

**delete observation if people left within a session (or fewer participants were in the session than expected)
keep if current_app_name == "finpay"

**gen treatment variable 0 for no stress, 1 for stress
gen treat = 0
replace treat = 1 if id_in_session < 7

* there was one person in session 20 (number 4) who was supposed to be stressed 
* but one of the panel members knew her, so we moved her to the no-stress condition:
replace treat = 0 if session == 20 & id_in_session == 4
gen matchingID = session * 100 + id_in_session


**generate number of safe choices
egen nrsafe = rowtotal(m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m21 m22 m23 m24 m25 m26 m27 m28 m29 m210)



* count number of (multiple) switches
* generate variables for switches list 1
forvalues i=2(1)10{
gen switch`i' = 0
}

replace switch2 = 1 if m2 != m1
replace switch3 = 1 if m3 != m2
replace switch4 = 1 if m4 != m3
replace switch5 = 1 if m5 != m4
replace switch6 = 1 if m6 != m5
replace switch7 = 1 if m7 != m6
replace switch8 = 1 if m8 != m7
replace switch9 = 1 if m9 != m8
replace switch10 = 1 if m10 != m9


* generate variables for switches list 2
forvalues i=2(1)10{
gen switch2`i' = 0
}


replace switch22 = 1 if m22 != m21
replace switch23 = 1 if m23 != m22
replace switch24 = 1 if m24 != m23
replace switch25 = 1 if m25 != m24
replace switch26 = 1 if m26 != m25
replace switch27 = 1 if m27 != m26
replace switch28 = 1 if m28 != m27
replace switch29 = 1 if m29 != m28
replace switch210 = 1 if m210 != m29

* switches list 1
egen multswitch1 = rowtotal(switch2 switch3 switch4 switch5 switch6 switch7 switch8 switch9 switch10) 
* multiple switches list1
replace multswitch1 = multswitch - 1 if multswitch != 0

* switches list 2
egen multswitch2 = rowtotal(switch22 switch23 switch24 switch25 switch26 switch27 switch28 switch29 switch210)
* multiple switches list 2
replace multswitch2 = multswitch2 - 1 if multswitch2 != 0


* multiple switches list 1 and 2 combined
gen summultswitch = multswitch1 + multswitch2
tab summultswitch


save data_cleaned.dta, replace


**# DESCRIPTIVES					
********************************************************************************
**************************** DESCRIPTIVES **************************************
********************************************************************************
* Table 3, main text

** GENDER
* for gender: 1 = male, 2 = female, 3 = other
* one "other"
tab gender
* 55.67% male subjects
tab gender if treat == 0
* 53.61% male subjects
tab gender if treat == 1
* 57.73% male subjects


**AGE
sum age, detail
* 20.7732 mean age
* 2.487295 SD
sum age if treat == 0
* 20.86598
* 2.477519 SD
sum age if treat == 1
* 20.68041
* 2.506435 


**CONTRACEPTIVE
 tab contraceptive if gender == 2
 *28.24% take oral contraceptives
 tab contraceptive if gender == 2 & treat == 0
 *27.27
 tab contraceptive if gender == 2 & treat == 1
 *29.27
 

** FIELD OF STUDY
* 1 Economics, 2 Business Administration, 3 Law, 4 Finance, 5 Law and Economics, 
* 6 Psychology, 7 Other
tab fieldstudy
* 47.42 % economics
* 21.65 % business administration
* 4.64 % law
* 8.25 % finance
* 18.04 % psychology (but equally distributed among treatment and control!)
tab fieldstudy if treat == 0
tab fieldstudy if treat == 1



********************************************************************************
***************** COMPLIANCE WITH THE ELIGIBILITY CRITERIA *********************
********************************************************************************
* Table 9, appendix

** 1 is yes, 2 is no
tab reg_med
*4.64% (9 people) take regular medication
tab med_ill
*3.09 (6 pople) have a medical condition
tab subs_abuse
*4.64% (9 people) regularly abuse substances
tab smoke
*6.7% (13 people) smoke regularly
tab coffee
*52.06% do not drink any coffee at all
*1 cup - 28.35%
*2 cups - 11.86%
*3 cups - 5.67%
*4 cups - 1.55%
*5 cups - 0.52%
tab abstain
*94.85% able to abstain from coffee for a day
tab self_stress
*15.46% of subjects self-reported severe stress lately
tab gum_bleeding
*100% report no gum bleeding
tab preg_breast
*no female is pregnant
tab eaten 
*94.33% of all subjects report that they have stopped eating two ´hours prior to the experiment
tab teeth
*90.72% reported that they have brushed their teeth
tab wakeup
*98.97% reported that they woke up in time
tab alcohol
*93.30% reported that they didn't have alcohol the past 24 hours


**# CORTISOL ANALYSIS
********************************************************************************
********************** CORTISOL ANALYSIS ***************************************
********************************************************************************
clear
import excel Numbering_Saliva.xlsx, cellrange(:E582) firstrow


**gen treatment variable 0 for no stress, 1 for stress
gen treat = 0
replace treat = 1 if SubjectID < 7

* there was one person in session 20 (number 4) who was supposed to be stressed 
* but one of the panel members knew them, so moved to control (c.f. above):
replace treat = 0 if SessionID == 20 & SubjectID == 4

*drop the outlier with very high cortisol
drop if SessionID == 5 & SubjectID == 8

*drop the subjects with at least one Saliva sample missing
drop if SessionID == 1 & SubjectID == 2
drop if SessionID == 1 & SubjectID == 3
drop if SessionID == 1 & SubjectID == 5
drop if SessionID == 2 & SubjectID == 9
drop if SessionID == 3 & SubjectID == 6
drop if SessionID == 8 & SubjectID == 3
drop if SessionID == 12 & SubjectID == 7 
drop if SessionID == 13 & SubjectID == 8 
drop if SessionID == 15 & SubjectID == 7 


***** Log-transform the data
gen logcortisol = log(Cortisol)

preserve
keep if SSalivaID == 1
ttest logcortisol, by(treat)
* 0.7855
restore

preserve
keep if SSalivaID == 2
ttest logcortisol, by(treat)
* 0.0000
restore

preserve
keep if SSalivaID == 3
ttest logcortisol, by(treat)
* 0.0000
restore


save salivadata1.dta, replace


* Figure 2, main text
preserve
collapse (mean) logcortisol (semean) se = logcortisol ,by(treat SSalivaID)

gen hi = logcortisol + se
gen lo = logcortisol - se
gen helper1 = SSalivaID - 0.15	
gen helper2 = SSalivaID + 0.20
	
twoway ///
	(bar logcortisol helper1 if treat==0, color(dknavy*0.8) barwidth(.35)) ///
	(bar logcortisol helper2 if treat==1, color(maroon*0.8) barwidth(.35)) ///
	, xlab(1(1)3) ///
	yt("Log Cortisol nmol/L") leg(order( 1 "no stress" 2 "stress") ) ///
	ylab(0(0.5)2.5, angle(horizontal)) ///
	yline(0(0.25)2.5, lcolor(gs14) lwidth(thin)) ///
	xsize(4) ///
	xlabel(1 "baseline" 2 "after stress task" 3 "at end") || ///
	(rcap hi lo helper1 if treat == 0, lcolor(black)) || ///
	(rcap hi lo helper2 if treat == 1, lcolor(black)) 
restore


clear
use data_cleaned.dta

ttest panas1_neg, by(treat)
* 0.5106
ttest panas21_neg, by(treat)
* 0.0000

preserve
collapse (mean) panas1_neg panas21_neg (semean) se1 = panas1_neg se2 = panas21_neg ,by(treat)

gen helper1 = 1.325 
gen helper2 = 1.675
gen helper3 = 2.825
gen helper4 = 3.175

gen hi1 = panas1_neg + se1
gen lo1 = panas1_neg - se1 
gen hi2 = panas21_neg + se2
gen lo2 = panas21_neg - se2

twoway ///
	(bar panas1_neg helper1 if treat==0, color(dknavy*0.8) barwidth(.35)) ///
	(bar panas1_neg helper2 if treat==1, color(maroon*0.8) barwidth(.35)) ///
	(bar panas21_neg helper3 if treat==0, color(dknavy*0.8) barwidth(.35)) ///
	(bar panas21_neg helper4 if treat==1, color(maroon*0.8) barwidth(.35)) ///
	, xlab(1(1)3) ///
	yt("Negative Affect - PANAS") leg(order( 1 "no stress" 2 "stress") ) ///
	ylab(0(5)25, angle(horizontal)) ///
	yline(0(2.5)25, lcolor(gs14) lwidth(thin)) ///
	xsize(4) ///
	xlabel(1.5 "baseline" 3 "after stress task") || ///
	(rcap hi1 lo1 helper1 if treat == 0, lcolor(black)) || ///
	(rcap hi1 lo1 helper2 if treat == 1, lcolor(black)) || ///
	(rcap hi2 lo2 helper3 if treat == 0, lcolor(black)) || ///
	(rcap hi2 lo2 helper4 if treat == 1, lcolor(black)) 
restore






********************************************************************************
***************** CORTISOL REACTIVITY ACROSS TREATMENTS ************************
********************************************************************************
clear
use salivadata1.dta

drop if SSalivaID == 3

** generate difference between 2nd and 1st sample
gen diffcortisol = logcortisol - logcortisol[_n-1]
replace diffcortisol = . if SSalivaID == 1

**** Cortisol response according to Miller et al. (2013)
sort SessionID SubjectID SSalivaID
gen diffcortisol2 = Cortisol - Cortisol[_n-1]
replace diffcortisol2 = . if SSalivaID == 1

gen response = 1 if diffcortisol2 >= 1.5 & diffcortisol2 != .
replace response = 0 if diffcortisol2 < 1.5 & diffcortisol2 != .

*** How many responders in treat and control?
tab response if treat == 1
* 52.69 %
tab response if treat == 0
* 5.49 %

keep if response != .

gen matchingID = SessionID * 100 + SubjectID

save salivadata.dta, replace



********************************************************************************
******************** REGRESSIONS OC FEMALE SESSIONTIME *************************
********************************************************************************
clear 
use data_cleaned.dta

merge 1:1 matchingID using salivadata.dta
keep if _merge == 3
drop _merge



*drop the outlier with very high cortisol 
// put next line in comments to reproduce table E.1 in appendix 
*drop if SessionID == 5 & SubjectID == 8

*generate Sessiontime 
* 1 = 10 - 12
* 2 = 13 - 15
* 3 = 16 - 18

gen sessiontime = .
replace sessiontime = 1 if SessionID == 1
replace sessiontime = 2 if SessionID == 2
replace sessiontime = 1 if SessionID == 3
replace sessiontime = 2 if SessionID == 4
replace sessiontime = 3 if SessionID == 5
replace sessiontime = 2 if SessionID == 7
replace sessiontime = 3 if SessionID == 8
replace sessiontime = 1 if SessionID == 9
replace sessiontime = 2 if SessionID == 10
replace sessiontime = 3 if SessionID == 11
replace sessiontime = 1 if SessionID == 12
replace sessiontime = 2 if SessionID == 13
replace sessiontime = 3 if SessionID == 14
replace sessiontime = 1 if SessionID == 15
replace sessiontime = 2 if SessionID == 16
replace sessiontime = 3 if SessionID == 17
replace sessiontime = 1 if SessionID == 18
replace sessiontime = 2 if SessionID == 19
replace sessiontime = 1 if SessionID == 20




* Table 10, appendix
replace contraceptive = 0 if contraceptive == 2
gen female = 1 if gender == 2
replace female = 0 if female == . 


reg diffcortisol treat sessiontime, robust
gen congender = female*contraceptive
replace congender = 0 if congender == .
drop if gender == 3
reg diffcortisol treat female congender, robust




**# RISK TAKING / NON-PARAMETRIC
********************************************************************************
******************** RISK TAKING / DESCRIPTIVE RESULTS *************************
********************************************************************************
clear
use data_cleaned.dta

* Table 4, main text

ttest nrsafe, by(treat)
* 0.3024
ttest summultswitch, by(treat)
* 0.2174
ttest crt_score, by(treat)
* 0.2731 




*** FIGURE 3, main text

preserve
keep id treat m* nrsafe
cumul nrsafe if treat==0, gen(nrsafec1)
cumul nrsafe if treat == 1, gen(nrsafec2)

replace nrsafec1 = nrsafec2 if nrsafec1 == .
sort nrsafec1 
	

twoway (line nrsafec1 nrsafe if treat == 0, ///
			lcolor(dknavy*0.75)) ///
	(line nrsafec1 nrsafe if treat == 1, ///
			lcolor(maroon*0.75) lpattern(dash)), ///
	legend(order(1 "no stress" 2 "stress" ) ring(0) position(10) bmargin(large)) ///
	ytitle("CDF of number of safe choices") ///
	xtitle("number of safe choices") ///
	yline(0(0.1)1, lcol(gs14)) ///
	ylabel(0(0.2)1, angle(horizontal)) 
	kwallis nrsafe, by(treat)
	* 0.2987
	
drop nrsafec1 nrsafec2

collapse (mean) meannrsafe = nrsafe (sd) sdnrsafe = nrsafe (count) n = nrsafe, by(treat)
gen hinrsafe = meannrsafe + invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))
gen lownrsafe = meannrsafe - invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))


graph twoway (bar meannrsafe treat if treat == 0, ///
	barwidth(0.65) ylabel(0(2)20, angle(horizontal)) color(dknavy*0.75) yline(0(2)20, lcol(gs14))) ///
	(bar meannrsafe treat if treat == 1, ///
	barwidth(0.65) ylabel(0(2)20) color(maroon*0.75) yline(0(2)20, lcol(gs14)) ///
	xlabel(0 "no stress" 1 "stress") ///
	ytitle("number of safe choices") xtitle("")) ///
	(rcap hinrsafe lownrsafe treat, lcol(black)), legend(off) ///
	xsize(4)
restore





*** Figure 4, main text
** number of multiple switches
preserve
keep id treat m* summultswitch
cumul summultswitch if treat == 0, gen(sumc1)
cumul summultswitch if treat == 1, gen(sumc2)

replace sumc1 = sumc2 if sumc1 == .
sort sumc1

twoway (line sumc1 summultswitch if treat == 0, ///
			lcolor(dknavy*0.75)) ///
	(line sumc2 summultswitch if treat == 1, ///
			lcolor(maroon*0.75) lpattern(dash)), ///
	legend(order(1 "no stress" 2 "stress" ) ring(0) position(4) bmargin(large)) ///
	ytitle("CDF of number of reverse switches") ///
	xtitle("number of reverse switches") ///
	yline(0(0.1)1, lcol(gs14)) ylabel(0(.2)1, angle(horizontal))
	kwallis summultswitch, by(treat)
	* 0.2015
	
drop sumc1 sumc2
	

collapse (mean) meansummultswitch = summultswitch (sd) sdsummultswitch = summultswitch (count) n = summultswitch, by(treat)
gen himultswitch = meansummultswitch + invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))
gen lowmultswitch = meansummultswitch - invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))


graph twoway (bar meansummultswitch treat if treat == 0, ///
	xlabel(0 "no stress" 1 "stress") barwidth(0.65) ylabel(1(1)10, angle(horizontal)) /// 
	color(maroon*0.75) yline(1(1)10, lcol(gs14))) /// 
	(bar meansummultswitch treat if treat == 1, barwidth(0.65) ///
		color(dknavy*0.75)) ///
	(rcap himultswitch lowmultswitch treat, lcol(black)), legend(off) ///
	ytitle("number of reverse switches") ///
	xsize(3) xtitle("")
restore





////////////////////////////////////////////////////////////////////////////////
********************************************************************************
******************** CRT MULTIPLE SWITCHES STRESS ******************************
********************************************************************************
*** Table 5, main text
*** Table 11, appendix 
clear
use data_cleaned.dta
 

reg summultswitch treat crt_score, vce(bootstrap)
oprobit summultswitch treat crt_score, vce(bootstrap)


gen treat_crt = treat*crt_score
reg summultswitch treat crt_score treat_crt, vce(bootstrap)
oprobit summultswitch treat crt_score treat_crt, vce(bootstrap)



**# RISK TAKING / PARAMETRIC

////////////////////////////////////////////////////////////////////////////////
********************************************************************************
************************ STRUCTURAL ESTIMATION *********************************
********************************************************************************
clear
use data_cleaned.dta


keep id m* treat gender

drop id max_page_index matchingID multswitch1 multswitch2 med_ill
gen id = _n

reshape long m m2, i(id) j(decision)

tab m 
tab m2

gen helper = 1 if m == 0
replace helper = 0 if m == 1

gen helper2 = 1 if m2 == 0
replace helper2 = 0 if m2 == 1

replace m = helper
replace m2 = helper2


// associate choices with actual "payoffs"

gen p1l = .
gen p2l = .
gen p1r = .
gen p2r = .

replace p1l = 0.5
replace p2l = 0.5
replace p1r = 0.5
replace p2r = 0.5


rename m choice
rename m2 choice2
gen endow = 0
gen ll = .

expand 2
gen trans = _n 
gen task = 1
replace task = 2 if trans > 1940
replace choice = choice2 if trans > 1940
drop trans


forvalues i = 1(1)4{
gen value`i' = .
}


replace value1 = 30 if task == 1
replace value2 = 50 if task == 1
replace value3 = 5 if task == 1
replace value4 = 60 if decision == 1 & task == 1
replace value4 = 70 if decision == 2 & task == 1
replace value4 = 80 if decision == 3 & task == 1
replace value4 = 90 if decision == 4 & task == 1
replace value4 = 100 if decision == 5 & task == 1
replace value4 = 110 if decision == 6 & task == 1
replace value4 = 120 if decision == 7 & task == 1
replace value4 = 140 if decision == 8 & task == 1
replace value4 = 170 if decision == 9 & task == 1
replace value4 = 220 if decision == 10 & task == 1



replace value1 = 25 if task == 2
replace value2 = 45 if task == 2
replace value3 = 2 if task == 2
replace value4 = 40 if decision == 1 & task == 2
replace value4 = 50 if decision == 2 & task == 2
replace value4 = 55 if decision == 3 & task == 2
replace value4 = 60 if decision == 4 & task == 2
replace value4 = 65 if decision == 5 & task == 2
replace value4 = 70 if decision == 6 & task == 2
replace value4 = 75 if decision == 7 & task == 2
replace value4 = 95 if decision == 8 & task == 2
replace value4 = 135 if decision == 9 & task == 2
replace value4 = 215 if decision == 10 & task == 2



**** The following is taken from  Harrison (2008) 
	* first for r only 

	
program define ML_eu1

 * specify the arguments of this program
 args lnf r
 
 * declare the temporary variables to be used
 tempvar c prob1l prob2l prob1r prob2r endow m1 m2 m3 m4 y1 y2 y3 y4 euL euR euDiff
 
 quietly {
 
 * initialize the data
 generate int `c' = $ML_y1
 generate double `prob1l' = $ML_y2
 generate double `prob2l' = $ML_y3

 
 generate double `prob1r' = $ML_y4
 generate double `prob2r' = $ML_y5

 
 
 generate double `m1' = $ML_y6
 generate double `m2' = $ML_y7
 generate double `m3' = $ML_y8
 generate double `m4' = $ML_y9
 generate double `endow' = $ML_y10
 
 
 * construct the argument of the utility function
 replace `m1' = `endow'+`m1'
 replace `m2' = `endow'+`m2'
 replace `m3' = `endow'+`m3'
 replace `m4' = `endow'+`m4'
 
 * evaluate the utility function
 generate double `y1' = `m1'^`r'
 generate double `y2' = `m2'^`r'
 generate double `y3' = `m3'^`r'
 generate double `y4' = `m4'^`r'
 
 * calculate EU of each lottery
 generate double `euL' = (`prob1l'*`y1')+(`prob2l'*`y2')
 generate double `euR' = (`prob1r'*`y3')+(`prob2r'*`y4')
 
 
 * get the Fechner index
 generate double `euDiff' = `euR' - `euL'
 
 
 * evaluate the likelihood
 replace `lnf' = ln(normal( `euDiff')) if `c'==1
 replace `lnf' = ln(normal(-`euDiff')) if `c'==0
 replace ll = `lnf'
}
end

ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 0, technique(bfgs) maximize vce(cluster id)
ml display
ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 1, technique(bfgs) maximize vce(cluster id)
ml display



* full sample
ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 0, technique(bfgs) maximize
estimates store nostress

ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 1, technique(bfgs) maximize
estimates store stress

suest nostress stress, cluster(id)
test [nostress_r]_cons = [stress_r]_cons
*p = 0.5962


** GENDER DIFFERENCES
* male
preserve
keep if gender == 1
ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 0, technique(bfgs) maximize
estimates store nostress_male

ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 1, technique(bfgs) maximize
estimates store stress_male

suest nostress_male stress_male, cluster(id)
test [nostress_male_r]_cons = [stress_male_r]_cons
* 0.8272
restore

*female
preserve
keep if gender == 2
ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 0, technique(bfgs) maximize
estimates store nostress_male

ml model lf ML_eu1 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) if treat == 1, technique(bfgs) maximize
estimates store stress_male

suest nostress_male stress_male, cluster(id)
test [nostress_male_r]_cons = [stress_male_r]_cons
* 0.3560
restore







// CHOICE ERROR FECHNER ERROR
program define ML_euF3
 * specify the arguments of this program
 args lnf r noise
 
 * declare the temporary variables to be used
 tempvar c prob1l prob2l prob1r prob2r endow m1 m2 m3 m4 y1 y2 y3 y4 l1 euL euR euDiff
 
 * please do not display all these steps on the screen, for every ML iteration!
 quietly {
 
 * initialize the data
 generate int `c' = $ML_y1
 generate double `prob1l' = $ML_y2
 generate double `prob2l' = $ML_y3

 
 generate double `prob1r' = $ML_y4
 generate double `prob2r' = $ML_y5

 
 
 generate double `m1' = $ML_y6
 generate double `m2' = $ML_y7
 generate double `m3' = $ML_y8
 generate double `m4' = $ML_y9
 generate double `endow' = $ML_y10
 
 
 * construct the argument of the utility function
 replace `m1' = `endow'+`m1'
 replace `m2' = `endow'+`m2'
 replace `m3' = `endow'+`m3'
 replace `m4' = `endow'+`m4'
 
 * evaluate the utility function
 generate double `y1' = `m1'^`r'
 generate double `y2' = `m2'^`r'
 generate double `y3' = `m3'^`r'
 generate double `y4' = `m4'^`r'
 
 * calculate EU of each lottery
 generate double `euL' = (`prob1l'*`y1')+(`prob2l'*`y2')
 generate double `euR' = (`prob1r'*`y3')+(`prob2r'*`y4')
 
 
 * get the Fechner index
 generate double `euDiff' = (`euR' - `euL') / (`noise')
 
 * transform
 generate double `l1' = 1/(1+exp(-`euDiff'))
 
 * evaluate the likelihood
replace `lnf' = ln(( `l1')) if `c'==1
replace `lnf' = ln((1 -`l1')) if `c'==0
 
 * save the calculated likelihood in an external storage variable
 replace ll = `lnf'
}
end

ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 0, technique(bfgs) maximize vce(cluster id)
ml display
estimates store nostress_fechner

ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 1, technique(bfgs) maximize vce(cluster id)
ml display
estimates store stress_fechner




ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_fechner

ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 1, technique(bfgs) maximize
estimates store stress_fechner


suest nostress_fechner stress_fechner, cluster(id)
test [nostress_fechner_r]_cons = [stress_fechner_r]_cons
* 0.3752
test [nostress_fechner_noise]_cons = [stress_fechner_noise]_cons
* 0.3788

** GENDER DIFFERENCES
* male
preserve
keep if gender == 1
ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_fechner_male

ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 1, technique(bfgs) maximize
estimates store stress_fechner_male


suest nostress_fechner_male stress_fechner_male, cluster(id)
test [nostress_fechner_male_r]_cons = [stress_fechner_male_r]_cons
* 0.9851
test [nostress_fechner_male_noise]_cons = [stress_fechner_male_noise]_cons
* 0.8943
restore


* female
preserve
keep if gender == 2
ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_fechner_female

ml model lf ML_euF3 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (noise: ) if treat == 1, technique(bfgs) maximize
estimates store stress_fechner_female


suest nostress_fechner_female stress_fechner_female, cluster(id)
test [nostress_fechner_female_r]_cons = [stress_fechner_female_r]_cons
* 0.0688
test [nostress_fechner_female_noise]_cons = [stress_fechner_female_noise]_cons
* 0.0945
restore









** With errors modelled
// CHOICE ERRORS IN EVALUATING EXPECTED UTILITIES --- LUCE MODEL!


program define ML_eu2

 * specify the arguments of this program
 args lnf r mu
 
 * declare the temporary variables to be used
 tempvar c prob1l prob2l prob1r prob2r endow m1 m2 m3 m4 y1 y2 y3 y4 euL euR euDiff
 
 quietly {
 
 * initialize the data
 generate int `c' = $ML_y1
 generate double `prob1l' = $ML_y2
 generate double `prob2l' = $ML_y3

 
 generate double `prob1r' = $ML_y4
 generate double `prob2r' = $ML_y5

 
 
 generate double `m1' = $ML_y6
 generate double `m2' = $ML_y7
 generate double `m3' = $ML_y8
 generate double `m4' = $ML_y9
 generate double `endow' = $ML_y10
 
 
 * construct the argument of the utility function
 replace `m1' = `endow'+`m1'
 replace `m2' = `endow'+`m2'
 replace `m3' = `endow'+`m3'
 replace `m4' = `endow'+`m4'
 
 * evaluate the utility function
 generate double `y1' = `m1'^`r'
 generate double `y2' = `m2'^`r'
 generate double `y3' = `m3'^`r'
 generate double `y4' = `m4'^`r'
 
 * calculate EU of each lottery
 generate double `euL' = (`prob1l'*`y1')+(`prob2l'*`y2')
 generate double `euR' = (`prob1r'*`y3')+(`prob2r'*`y4')
 
 
 * get the Fechner index
 ************ this is the critical point here - LUCE 
 generate double `euDiff' = (`euR'^(1/`mu'))/((`euR'^(1/`mu'))+(`euL'^(1/`mu')))
 
 
 * evaluate the likelihood
 **** logarithmic specification
 replace `lnf' = ln( `euDiff') if `c'==1
 replace `lnf' = ln(1-`euDiff') if `c'==0
 
 replace ll = `lnf'
}
end

ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 0, technique(bfgs) maximize vce(cluster id)
ml display

ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 1, technique(bfgs) maximize vce(cluster id)
ml display



ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_noise
ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 1, technique(bfgs) maximize
estimates store stress_noise

suest nostress_noise stress_noise, cluster(id)
test [nostress_noise_r]_cons = [stress_noise_r]_cons
* 0.3586
test [nostress_noise_mu]_cons = [stress_noise_mu]_cons
*  0.6000

** GENDER DIFFERENCES
* male
preserve
keep if gender == 1
ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_noise_male
ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 1, technique(bfgs) maximize
estimates store stress_noise_male

suest nostress_noise_male stress_noise_male, cluster(id)
test [nostress_noise_male_r]_cons = [stress_noise_male_r]_cons
* 0.9786
test [nostress_noise_male_mu]_cons = [stress_noise_male_mu]_cons
* 0.7230

restore

* female
preserve
keep if gender == 2
ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 0, technique(bfgs) maximize 
estimates store nostress_noise_female
ml model lf ML_eu2 (r: choice p1l p2l p1r p2r value1 value2 value3 value4 endow = ) (mu: ) if treat == 1, technique(bfgs) maximize
estimates store stress_noise_female

suest nostress_noise_female stress_noise_female, cluster(id)
test [nostress_noise_female_r]_cons = [stress_noise_female_r]_cons
* 0.0664
test [nostress_noise_female_mu]_cons = [stress_noise_female_mu]_cons
* 0.2703

restore








**# Exploratory: Gender

////////////////////////////////////////////////////////////////////////////////
********************************************************************************
********************************************************************************

clear
use data_cleaned.dta
 
tab gender
*gender = 1: male

ranksum nrsafe if gender == 1, by(treat)
ranksum nrsafe if gender == 2, by(treat)

* Figure 5, main text
** # safe choices 
preserve
keep if gender == 1
cumul nrsafe if treat==0, gen(nrsafec1)
cumul nrsafe if treat == 1, gen(nrsafec2)

replace nrsafec1 = nrsafec2 if nrsafec1 == .
sort nrsafec1 
	
twoway (line nrsafec1 nrsafe if treat == 0, ///
			lcolor(maroon*0.75) lpattern(dash)) ///
	(line nrsafec1 nrsafe if treat == 1, ///
			lcolor(dknavy*0.75)), ///
	legend(order(1 "no stress" 2 "stress") pos(10) ring(0) col(1)) ///
	ytitle("CDF of number of safe choices") ///
	xtitle("number of safe choices") ///
	yline(0(0.1)1, lcol(gs14))
	kwallis nrsafe, by(treat)
	* 0.9409
restore



preserve
keep if gender == 2
cumul nrsafe if treat==0, gen(nrsafec1)
cumul nrsafe if treat == 1, gen(nrsafec2)

replace nrsafec1 = nrsafec2 if nrsafec1 == .
sort nrsafec1 
	

twoway (line nrsafec1 nrsafe if treat == 0, ///
			lcolor(maroon*0.75) lpattern(dash)) ///
	(line nrsafec1 nrsafe if treat == 1, ///
			lcolor(dknavy*0.75)), ///
	legend(order(1 "no stress" 2 "stress") pos(10) ring(0) col(1)) ///
	ytitle("CDF of number of safe choices") ///
	xtitle("number of safe choices") ///
	yline(0(0.1)1, lcol(gs14))
	kwallis nrsafe, by(treat)
	* 0.0380
restore



* Figure 6, main text
preserve
keep if gender == 1
cumul summultswitch if treat == 0, gen(sumc1)
cumul summultswitch if treat == 1, gen(sumc2)

replace sumc1 = sumc2 if sumc1 == .
sort sumc1

twoway (line sumc1 summultswitch if treat == 0, ///
			lcolor(maroon*0.75) lpattern(dash)) ///
	(line sumc2 summultswitch if treat == 1, ///
			lcolor(dknavy*0.75)), ///
	legend(order(1 "no stress" 2 "stress" ) pos(5) ring(0) col(1)) ///
	ytitle("CDF of number of reverse switches") ///
	xtitle("number of reverse switches") ///
	yline(0(0.1)1, lcol(gs14))
	kwallis summultswitch, by(treat)
	* 0.6595
restore


preserve
keep if gender == 2
cumul summultswitch if treat == 0, gen(sumc1)
cumul summultswitch if treat == 1, gen(sumc2)

replace sumc1 = sumc2 if sumc1 == .
sort sumc1

twoway (line sumc1 summultswitch if treat == 0, ///
			lcolor(maroon*0.75) lpattern(dash)) ///
	(line sumc2 summultswitch if treat == 1, ///
			lcolor(dknavy*0.75)), ///
	legend(order(1 "no stress" 2 "stress" ) pos(5) ring(0) col(1)) ///
	ytitle("CDF of number of reverse switches") ///
	xtitle("number of reverse switches") ///
	yline(0(0.1)1, lcol(gs14))
	kwallis summultswitch, by(treat)
	* 0.1284
restore




**# ROBUSTNESS CHECKS

////////////////////////////////////////////////////////////////////////////////
********************************************************************************
***************** ANALYSIS SESSION DISRUPTIVE PARTICIPANT **********************
********************************************************************************
** We do not have saliva samples in that session

clear
use data_full_raw_plus6.dta


**delete observation if people left within a session
keep if current_app_name == "finpay"

**gen treatment variable 0 for no stress, 1 for stress
gen treat = 0
replace treat = 1 if id_in_session < 7

* there was one person in session 20 (number 4) who was supposed to be stressed 
* 	but one of the panel members knew her, so we moved her to the no-stress condition:
replace treat = 0 if session == 20 & id_in_session == 4


**generate number of safe choices
egen nrsafe = rowtotal(m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m21 m22 m23 m24 m25 m26 m27 m28 m29 m210)



* count number of (multiple) switches
* generate variables for switches list 1
forvalues i=2(1)10{
gen switch`i' = 0
}

replace switch2 = 1 if m2 != m1
replace switch3 = 1 if m3 != m2
replace switch4 = 1 if m4 != m3
replace switch5 = 1 if m5 != m4
replace switch6 = 1 if m6 != m5
replace switch7 = 1 if m7 != m6
replace switch8 = 1 if m8 != m7
replace switch9 = 1 if m9 != m8
replace switch10 = 1 if m10 != m9


* generate variables for switches list 2
forvalues i=2(1)10{
gen switch2`i' = 0
}


replace switch22 = 1 if m22 != m21
replace switch23 = 1 if m23 != m22
replace switch24 = 1 if m24 != m23
replace switch25 = 1 if m25 != m24
replace switch26 = 1 if m26 != m25
replace switch27 = 1 if m27 != m26
replace switch28 = 1 if m28 != m27
replace switch29 = 1 if m29 != m28
replace switch210 = 1 if m210 != m29

* switches list 1
egen multswitch1 = rowtotal(switch2 switch3 switch4 switch5 switch6 switch7 switch8 switch9 switch10) 
* multiple switches list1
replace multswitch1 = multswitch - 1 if multswitch != 0

* switches list 2
egen multswitch2 = rowtotal(switch22 switch23 switch24 switch25 switch26 switch27 switch28 switch29 switch210)
* multiple switches list 2
replace multswitch2 = multswitch2 - 1 if multswitch2 != 0


* multiple switches list 1 and 2 combined
gen summultswitch = multswitch1 + multswitch2
tab summultswitch

save data_cleaned2.dta, replace



**PANAS SCALE TEST -- is self-reported stress level different across treatments

ttest panas1_neg, by(treat)
* 0.5533
ttest panas21_neg, by(treat)
* 0.0000

ttest crt_score, by(treat)
*0.3696



*Figure 7, appendix

*** check whether number of safe choices changes significantly across treatments
preserve
keep id treat m* nrsafe
ttest nrsafe, by(treat)
* 0.5687 
** graph for number of safe choices between treatments with 95% confidence interval

collapse (mean) meannrsafe = nrsafe (sd) sdnrsafe = nrsafe (count) n = nrsafe, by(treat)
gen hinrsafe = meannrsafe + invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))
gen lownrsafe = meannrsafe - invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))

label variable treat "Treatment"

graph twoway (bar meannrsafe treat if treat == 0, ///
	barwidth(0.65) ylabel(0(2)20, angle(horizontal)) color(maroon*0.75) yline(0(2)20, lcol(gs14))) ///
	(bar meannrsafe treat if treat == 1, ///
	barwidth(0.65) ylabel(0(2)20) color(dknavy*0.75) yline(0(2)20, lcol(gs14)) ///
	xlabel(0 "no stress" 1 "stress") ///
	ytitle("number of safe choices") ///
	title("Mean Number of Safe Choices", size(medium))) ///
	(rcap hinrsafe lownrsafe treat, lcol(black)), legend(off) ///
	xsize(3)
restore



** number of multiple switches
preserve
keep id treat m* summultswitch nrsafe
ttest summultswitch, by(treat)
* 0.2517   

collapse (mean) meansummultswitch = summultswitch (sd) sdsummultswitch = summultswitch (count) n = summultswitch, by(treat)
gen himultswitch = meansummultswitch + invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))
gen lowmultswitch = meansummultswitch - invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))

graph twoway (bar meansummultswitch treat if treat == 0, ///
	xlabel(0 "no stress" 1 "stress") barwidth(0.65) ylabel(1(1)10, angle(horizontal)) /// 
	color(maroon*0.75) yline(1(1)10, lcol(gs14))) /// 
	(bar meansummultswitch treat if treat == 1, barwidth(0.65) ///
		color(dknavy*0.75)) ///
	(rcap himultswitch lowmultswitch treat, lcol(black)), legend(off) ///
	title("Mean Number of Multiple Switches", size(medium)) ///
	ytitle("number of multiple switches") ///
	xsize(3)
restore





////////////////////////////////////////////////////////////////////////////////
********************************************************************************
***************** ANALYSIS CORTISOL RESPONDERS ONLY ****************************
********************************************************************************

clear 
use data_cleaned.dta

merge 1:1 matchingID using salivadata.dta
keep if _merge == 3

tab treat
*92 in control, 93 in treatment

keep id treat response m* nrsafe summultswitch panas1_neg panas21_neg crt_score	
keep if response == 1 | treat == 0


ttest panas1_neg, by(treat)
* 0.8957
ttest panas21_neg, by(treat)
* 0.0000 
ttest crt_score, by(treat)
* 0.0151  
ttest nrsafe, by(treat)
* 0.9571  

	
* Figure 8, appendix
** graph for number of safe choices between treatments 
preserve
collapse (mean) meannrsafe = nrsafe (sd) sdnrsafe = nrsafe (count) n = nrsafe, by(treat)
gen hinrsafe = meannrsafe + invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))
gen lownrsafe = meannrsafe - invttail(n-1, 0.025)*(sdnrsafe / sqrt(n))
graph twoway (bar meannrsafe treat if treat == 0, ///
	barwidth(0.65) ylabel(0(2)20, angle(horizontal)) color(maroon*0.75) yline(0(2)20, lcol(gs14))) ///
	(bar meannrsafe treat if treat == 1, ///
	barwidth(0.65) ylabel(0(2)20) color(dknavy*0.75) yline(0(2)20, lcol(gs14)) ///
	xlabel(0 "no stress" 1 "stress") ///
	ytitle("number of safe choices") ///
	title("Mean Number of Safe Choices", size(medium))) ///
	(rcap hinrsafe lownrsafe treat, lcol(black)), legend(off) ///
	xsize(3)
restore



** graph for number of multiple switches
preserve
keep id treat m* summultswitch nrsafe response

ttest summultswitch, by(treat)
* 0.1433   
collapse (mean) meansummultswitch = summultswitch (sd) sdsummultswitch = summultswitch (count) n = summultswitch, by(treat)
gen himultswitch = meansummultswitch + invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))
gen lowmultswitch = meansummultswitch - invttail(n-1, 0.025)*(sdsummultswitch / sqrt(n))
graph twoway (bar meansummultswitch treat if treat == 0, ///
	xlabel(0 "no stress" 1 "stress") barwidth(0.65) ylabel(1(1)10, angle(horizontal)) /// 
	color(maroon*0.75) yline(1(1)10, lcol(gs14))) /// 
	(bar meansummultswitch treat if treat == 1, barwidth(0.65) ///
		color(dknavy*0.75)) ///
	(rcap himultswitch lowmultswitch treat, lcol(black)), legend(off) ///
	title("Mean Number of Reverse Switches", size(medium)) ///
	ytitle("number of reverse switches") ///
	xsize(3)
restore

